==> ah-form-builder-sample-0.6.19.tgz: package/es/components/toolbar/field-forms/Date.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/components/toolbar/field-forms/Date.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import SimpleTabs from "../../../utils/Tabs/SimpleTabs";
import TextInput from "../../../utils/inputs/TextInput";
import Checkbox from "../../../utils/checkboxs/Checkbox";
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, updateField as _updateField, deleteNewField as _deleteNewField } from "../../../actions/formActions";
import { connect } from "react-redux";
import DateValidation from "../../../utils/date-validation";
import { InputLabel } from '@material-ui/core';
import RichTextEditor from '../../../utils/rich-text-editor';
import { Scrollbars } from 'react-custom-scrollbars';
import SearchableSelect from '../../../utils/selects/SearchableSelect';
import ConditionalLogic from '../../../utils/conditional-logic';
import { getHeight } from '../../../utils/helpers';

var Select = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Select, _React$Component);

  function Select(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleTabChange", function (e, newValue) {
      _this.setState({
        activeTab: newValue
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          conditionalLogic = _this$state.conditionalLogic,
          isRequired = _this$state.isRequired,
          placeholder = _this$state.placeholder,
          helpText = _this$state.helpText,
          subType = _this$state.subType,
          visibility = _this$state.visibility,
          uuid = _this$state.uuid,
          type = _this$state.type,
          isMultiple = _this$state.isMultiple,
          shouldDateValidate = _this$state.shouldDateValidate,
          dateValidations = _this$state.dateValidations,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          conditionalLogic: conditionalLogic,
          isRequired: isRequired,
          placeholder: placeholder,
          helpText: helpText,
          subType: subType,
          visibility: visibility,
          isMultiple: isMultiple,
          shouldDateValidate: shouldDateValidate,
          dateValidations: dateValidations
        }
      };
      ValidateField(newField).then(function () {
        _this.props.updateField(newField);

        _this.props.disableFieldEdit();
      })["catch"](function (errors) {
        var keys = Object.keys(errors);

        if (keys[0] === 'machineName' || keys[0] === 'conditionalLogic') {
          _this.handleTabChange({}, 'advance');
        } else {
          _this.handleTabChange({}, 'basic');
        }

        _this.setState({
          errors: errors
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "handleDateValidationChange", function (value, name) {
      if (name === 'shouldDateValidate') {
        if (!value) {
          var _this$setState2;

          _this.setState((_this$setState2 = {}, _this$setState2[name] = value, _this$setState2.dateValidations = {
            pastUnit: 'days',
            pastMax: 0,
            pastMin: 0,
            futureUnit: 'days',
            futureMax: 0,
            futureMin: 0
          }, _this$setState2));
        } else {
          var _this$setState3;

          _this.setState((_this$setState3 = {}, _this$setState3[name] = value, _this$setState3));
        }
      } else {
        var _extends2;

        _this.setState({
          dateValidations: _extends({}, _this.state.dateValidations, (_extends2 = {}, _extends2[name] = value, _extends2))
        });
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderTabFields", function () {
      if (_this.state.activeTab === 'basic') {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 105,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement(Checkbox, {
          checked: _this.state.isRequired,
          handleChange: function handleChange(val) {
            return _this.handleDataChange(val, 'isRequired');
          },
          label: "Required",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 106,
            columnNumber: 11
          }
        }), /*#__PURE__*/React.createElement("div", {
          className: "mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 107,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.name,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'name');
          },
          label: "Field Name",
          required: true,
          autoFocus: true,
          error: _this.state.errors.name,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 108,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 110,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.helpText,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'helpText');
          },
          label: "Help Text",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 111,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 113,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(DateValidation, _extends({
          shouldDateValidate: _this.state.shouldDateValidate,
          handleChange: _this.handleDateValidationChange
        }, _this.state.dateValidations, {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 114,
            columnNumber: 13
          }
        }))));
      } else {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 120,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement("div", {
          className: "mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 121,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.machineName,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'machineName');
          },
          label: "Machine Name/Field ID",
          required: true,
          autoFocus: true,
          error: _this.state.errors.machineName,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 122,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 124,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(SearchableSelect, {
          options: [{
            label: 'Visible',
            value: 'visible'
          }, {
            label: 'Hidden',
            value: 'hidden'
          }],
          label: "Visibility to Employee",
          value: _this.state.visibility ? 'visible' : 'hidden',
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value === 'visible', 'visibility');
          },
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 125,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement(ConditionalLogic, {
          predefined: _this.props.predefined,
          conditionalLogic: _this.state.conditionalLogic,
          isConditionalEnabled: _this.state.isConditionalEnabled,
          handleChange: _this.handleDataChange,
          errors: _this.state.errors.conditionalLogic ? _this.state.errors.conditionalLogic : [],
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 127,
            columnNumber: 11
          }
        }));
      }
    });

    _this.state = _extends({
      activeTab: 'basic',
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName,
      isConditionalEnabled: !!props.data.config.conditionalLogic.length
    }, props.data.config);
    return _this;
  }

  var _proto = Select.prototype;

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 135,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(SimpleTabs, {
      value: this.state.activeTab,
      handleChange: this.handleTabChange,
      options: [{
        label: 'Basic Settings',
        value: 'basic'
      }, {
        label: 'Advance Settings',
        value: 'advance'
      }],
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 136,
        columnNumber: 9
      }
    }), /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, true)
      },
      autoHide: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 137,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "p-3 my-3",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 138,
        columnNumber: 11
      }
    }, this.renderTabFields(), /*#__PURE__*/React.createElement("div", {
      className: "width-full text-right",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 140,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      color: "primary",
      className: "mr-2",
      onClick: this.cancelEdit,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 141,
        columnNumber: 15
      }
    }, "Cancel"), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      color: "primary",
      disableElevation: true,
      onClick: this.saveField,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 144,
        columnNumber: 15
      }
    }, "Save")))));
  };

  return Select;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    predefined: state.form.predefined
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Select);

==> ah-form-builder-sample-0.6.82.tgz: package/es/components/toolbar/field-forms/Date.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/components/toolbar/field-forms/Date.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import SimpleTabs from "../../../utils/Tabs/SimpleTabs";
import TextInput from "../../../utils/inputs/TextInput";
import Checkbox from "../../../utils/checkboxs/Checkbox";
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, updateField as _updateField, deleteNewField as _deleteNewField } from "../../../actions/formActions";
import { connect } from "react-redux";
import DateValidation from "../../../utils/date-validation";
import { InputLabel } from '@material-ui/core';
import RichTextEditor from '../../../utils/rich-text-editor';
import { Scrollbars } from 'react-custom-scrollbars';
import SearchableSelect from '../../../utils/selects/SearchableSelect';
import ConditionalLogic from '../../../utils/conditional-logic';
import { getHeight } from '../../../utils/helpers';
import FieldRenderer from './utils/FieldRenderer';
import { radioFieldsConfigs } from './utils/radioFieldConfigs';
import { dateFieldsConfigs } from './utils/dateFieldConfigs';
import { processLocalFields } from './utils/helpers';
var basicTabTitle = {
  en: 'Basic Settings',
  ar: 'الإعدادات الأساسية'
};
var advanceTabTitle = {
  en: 'Advance Settings',
  ar: 'إعدادات متقدمة'
};
var machineNameLabel = {
  en: 'Machine Name/Field ID',
  ar: 'إسم الألة'
};
var visibilityLabel = {
  en: 'Visibility to Employee',
  ar: 'الرؤية للموظف'
};
var cancelLabel = {
  en: 'Cancel',
  ar: 'إلغاء'
};
var saveLabel = {
  en: 'Save',
  ar: 'حفظ'
};
var visibleLabel = {
  en: 'Visible',
  ar: 'مرئي'
};
var hiddenLabel = {
  en: 'Hidden',
  ar: 'مختفي'
};

var Select = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Select, _React$Component);

  function Select(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleTabChange", function (e, newValue) {
      _this.setState({
        activeTab: newValue
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          conditionalLogic = _this$state.conditionalLogic,
          isRequired = _this$state.isRequired,
          placeholder = _this$state.placeholder,
          helpText = _this$state.helpText,
          subType = _this$state.subType,
          visibility = _this$state.visibility,
          uuid = _this$state.uuid,
          type = _this$state.type,
          isMultiple = _this$state.isMultiple,
          shouldDateValidate = _this$state.shouldDateValidate,
          dateValidations = _this$state.dateValidations,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          conditionalLogic: conditionalLogic,
          isConditionalEnabled: !!conditionalLogic.conditions.length,
          isRequired: isRequired,
          placeholder: placeholder,
          helpText: helpText,
          subType: subType,
          visibility: visibility,
          isMultiple: isMultiple,
          shouldDateValidate: shouldDateValidate,
          dateValidations: dateValidations
        }
      };
      newField.locals = processLocalFields(_this.props.locals, _this.state);
      ValidateField(newField).then(function () {
        _this.props.updateField(newField);

        _this.props.disableFieldEdit();
      })["catch"](function (errors) {
        var keys = Object.keys(errors);

        if (keys[0] === 'machineName' || keys[0] === 'conditionalLogic') {
          _this.handleTabChange({}, 'advance');
        } else {
          _this.handleTabChange({}, 'basic');
        }

        _this.setState({
          errors: errors
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "handleDateValidationChange", function (value, name) {
      if (name === 'shouldDateValidate') {
        if (!value) {
          var _this$setState2;

          _this.setState((_this$setState2 = {}, _this$setState2[name] = value, _this$setState2.dateValidations = {
            pastUnit: 'days',
            pastMax: 0,
            pastMin: 0,
            futureUnit: 'days',
            futureMax: 0,
            futureMin: 0
          }, _this$setState2));
        } else {
          var _this$setState3;

          _this.setState((_this$setState3 = {}, _this$setState3[name] = value, _this$setState3));
        }
      } else {
        if (name === 'shouldPastDateValidate') {
          var _extends2;

          _this.setState({
            dateValidations: _extends({}, _this.state.dateValidations, (_extends2 = {}, _extends2[name] = value, _extends2.pastUnit = 'days', _extends2.pastMax = 0, _extends2.pastMin = 0, _extends2))
          });
        } else if (name === 'shouldFutureDateValidate') {
          var _extends3;

          _this.setState({
            dateValidations: _extends({}, _this.state.dateValidations, (_extends3 = {}, _extends3[name] = value, _extends3.futureUnit = 'days', _extends3.futureMax = 0, _extends3.futureMin = 0, _extends3))
          });
        } else {
          var _extends4;

          _this.setState({
            dateValidations: _extends({}, _this.state.dateValidations, (_extends4 = {}, _extends4[name] = value, _extends4))
          });
        }
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderTabFields", function () {
      if (_this.state.activeTab === 'basic') {
        var _this$state$errors;

        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 184,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement(FieldRenderer, _extends({}, _this.state, {
          locals: _this.props.locals,
          fieldConfigs: dateFieldsConfigs,
          handleDataChange: _this.handleDataChange,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 185,
            columnNumber: 11
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 199,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(DateValidation, _extends({
          currentLang: _this.props.currentLang,
          errors: (_this$state$errors = _this.state.errors) == null ? void 0 : _this$state$errors.dateErrors,
          shouldDateValidate: _this.state.shouldDateValidate,
          handleChange: _this.handleDateValidationChange
        }, _this.state.dateValidations, {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 200,
            columnNumber: 13
          }
        }))));
      } else {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 206,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 207,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.machineName,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'machineName');
          },
          label: machineNameLabel[_this.props.currentLang],
          required: true,
          autoFocus: true,
          error: _this.state.errors.machineName,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 208,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 210,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(SearchableSelect, {
          options: [{
            label: visibleLabel[_this.props.currentLang],
            value: 'visible'
          }, {
            label: hiddenLabel[_this.props.currentLang],
            value: 'hidden'
          }],
          label: visibilityLabel[_this.props.currentLang],
          value: _this.state.visibility ? 'visible' : 'hidden',
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value === 'visible', 'visibility');
          },
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 211,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement(ConditionalLogic, {
          predefined: _this.props.predefined,
          conditionalLogic: _this.state.conditionalLogic,
          isConditionalEnabled: _this.state.isConditionalEnabled,
          handleChange: _this.handleDataChange,
          errors: _this.state.errors.conditionalLogic ? _this.state.errors.conditionalLogic : [],
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 213,
            columnNumber: 11
          }
        }));
      }
    });

    _this.state = _extends({
      activeTab: 'basic',
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName
    }, props.data.config);
    return _this;
  }

  var _proto = Select.prototype;

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.data.uuid !== this.state.uuid) {
      this.setState(_extends({
        activeTab: 'basic',
        errors: {},
        uuid: nextProps.data.uuid,
        name: nextProps.data.name,
        type: nextProps.data.type,
        order: nextProps.data.order,
        parentId: nextProps.data.parentId,
        machineName: nextProps.data.machineName
      }, nextProps.data.config));
    }
  };

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 221,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(SimpleTabs, {
      value: this.state.activeTab,
      handleChange: this.handleTabChange,
      options: [{
        label: basicTabTitle[this.props.currentLang],
        value: 'basic'
      }, {
        label: advanceTabTitle[this.props.currentLang],
        value: 'advance'
      }],
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 222,
        columnNumber: 9
      }
    }), /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, true)
      },
      autoHide: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 223,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-p-3 ahfb-my-3",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 224,
        columnNumber: 11
      }
    }, this.renderTabFields(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 226,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      color: "primary",
      className: "ahfb-mr-2",
      onClick: this.cancelEdit,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 227,
        columnNumber: 15
      }
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      color: "primary",
      disableElevation: true,
      onClick: this.saveField,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 230,
        columnNumber: 15
      }
    }, saveLabel[this.props.currentLang])))));
  };

  return Select;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    predefined: state.form.predefined,
    locals: state.form.locals,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Select);
